@@ -14,6 +14,7 @@
 
 import datetime
 import os.path
+import pathlib
 
 from typing import Optional
 
@@ -42,6 +43,17 @@ class MetastoreReader(MetastoreReaderBase):
     a KeyError will be raised.
     """
 
+    def _read_table(self, table_format: TableFormat, path: str) -> DataFrame:
+        return self.spark.read.format(table_format.value).load(path)
+
+    def _apply_uppercase_to_columns_names(
+        self, df: DataFrame, uppercase_columns: bool
+    ) -> DataFrame:
+        if uppercase_columns:
+            return df.select([F.col(c).alias(c.upper()) for c in df.columns])
+        else:
+            return df
+
     def get_table(
         self,
         table_name: str,
@@ -51,6 +63,7 @@ class MetastoreReader(MetastoreReaderBase):
     ) -> DataFrame:
         """Get the table based on its name and config attributes.
 
+        :param table_name:
         :param info_date_from: optional param with info_date as default
         :param info_date_to: optional param with info_date as default
         :param uppercase_columns: returns a table with uppercase column names
@@ -60,36 +73,37 @@ class MetastoreReader(MetastoreReaderBase):
         The data format (and other options) are obtained from the config.
         """
 
-        info_date_from = info_date_from or self.info_date
-        info_date_to = info_date_to or self.info_date
+        metastore_table = get_metastore_table(table_name, self.config)
+        info_date_from_str = convert_date_to_str(
+            info_date_from or self.info_date,
+            fmt=metastore_table.info_date_settings.format,
+        )
+        info_date_to_str = convert_date_to_str(
+            info_date_to or self.info_date,
+            fmt=metastore_table.info_date_settings.format,
+        )
 
-        table = get_metastore_table(table_name, self.config)
+        logger.info(
+            f"Looking for {table_name} in the metastore where\n"
+            f"info_date in range: {info_date_from_str} - {info_date_to_str}."
+        )
 
-        logger.info(f"Looking for {table_name} in the metastore.")
-        logger.debug(f"info_date range: {info_date_from} - {info_date_to}")
+        df = self._read_table(metastore_table.format, metastore_table.path)
+        df_filtered = df.filter(
+            F.col(metastore_table.info_date_settings.column)
+            >= F.lit(info_date_from_str),
+        ).filter(
+            F.col(metastore_table.info_date_settings.column)
+            <= F.lit(info_date_to_str),
+        )
 
-        if table.format is TableFormat.parquet:
-            df = (
-                self.spark.read.parquet(table.path)
-                .filter(
-                    F.col(table.info_date_settings.column) >= info_date_from,
-                )
-                .filter(
-                    F.col(table.info_date_settings.column) <= info_date_to,
-                )
-            )
-        # TODO #38 support delta format
-        elif table.format is TableFormat.delta:
-            raise NotImplementedError
-        else:
-            raise NotImplementedError
         logger.info(
-            f"Table {table_name} successfully loaded from {table.path}."
+            f"Table {table_name} successfully loaded from {metastore_table.path}."
+        )
+
+        return self._apply_uppercase_to_columns_names(
+            df_filtered, uppercase_columns
         )
-        if uppercase_columns:
-            return df.select([F.col(c).alias(c.upper()) for c in df.columns])
-        else:
-            return df
 
     def get_latest(
         self,
@@ -106,33 +120,38 @@ class MetastoreReader(MetastoreReaderBase):
         until = until or self.info_date
         logger.info(f"Getting latest partition for {table_name} until {until}")
 
-        table = get_metastore_table(table_name, self.config)
+        metastore_table = get_metastore_table(table_name, self.config)
         latest_date = convert_date_to_str(
             self.get_latest_available_date(table_name, until),
-            fmt=table.info_date_settings.format,
+            fmt=metastore_table.info_date_settings.format,
         )
-        path = os.path.join(
-            table.path,
-            f"{table.info_date_settings.column}={latest_date}",
-        )
-        logger.debug(f"Path to the latest partition is: {path}")
-        if table.format is TableFormat.parquet:
-            df = self.spark.read.parquet(path).withColumn(
-                table.info_date_settings.column,
+
+        if metastore_table.format == TableFormat.parquet:
+            path = os.path.join(
+                metastore_table.path,
+                f"{metastore_table.info_date_settings.column}={latest_date}",
+            )
+            df = self._read_table(
+                metastore_table.format, pathlib.Path(path).as_posix()
+            ).withColumn(
+                metastore_table.info_date_settings.column,
                 F.lit(latest_date).cast(T.DateType()),
             )
-        elif table.format is TableFormat.delta:
-            raise NotImplementedError
+        elif metastore_table.format == TableFormat.delta:
+            df = self._read_table(
+                metastore_table.format, metastore_table.path
+            ).filter(
+                F.col(metastore_table.info_date_settings.column)
+                == F.lit(latest_date)
+            )
         else:
             raise NotImplementedError
+
         logger.info(
-            f"Table {table_name} with the latest partition {latest_date} "
-            f"loaded"
+            f"Table {table_name} with the latest partition {latest_date} loaded"
         )
-        if uppercase_columns:
-            return df.select([F.col(c).alias(c.upper()) for c in df.columns])
-        else:
-            return df
+
+        return self._apply_uppercase_to_columns_names(df, uppercase_columns)
 
     def get_latest_available_date(
         self,
