@@ -44,7 +44,9 @@ DATE_FMTS = {
     "yyyy-MM-dd": "%Y-%m-%d",
     "yyyyMMdd": "%Y%m%d",
 }
+
 DEFAULT_DATE_FMT = "yyyy-MM-dd"
+
 SPARK_DEFAULT_CONFIG = {
     "spark.master": "yarn",
     "spark.submit.deployMode": "client",
@@ -139,16 +141,14 @@ def get_or_create_spark_session(
     environment variable PRAMENPY_SPARK_CONFIG
     """
     logger.info("Preparing SparkSession")
-    os.environ.update(
-        {
-            "JAVA_HOME": env.str(
-                "PRAMENPY_SPARK_JAVA_HOME",
-                os.environ.get("JAVA_HOME", ""),
-            )
-        }
-    )
 
-    maybe_active_session = SparkSession.getActiveSession()
+    if env.str("PRAMENPY_SPARK_JAVA_HOME", ""):
+        os.environ.update({"JAVA_HOME": env.str("PRAMENPY_SPARK_JAVA_HOME")})
+        logger.info(
+            "JAVA_HOME is set to " + env.str("PRAMENPY_SPARK_JAVA_HOME")
+        )
+
+    maybe_active_session = SparkSession.getActiveSession()  # type: ignore
     if maybe_active_session and force_recreate:
         logger.info("Force recreating a spark session")
         spark = maybe_active_session
@@ -171,7 +171,7 @@ def get_or_create_spark_session(
 
     spark = session.getOrCreate()
     logger.info("SparkSession is ready")
-    return spark
+    return spark  # type: ignore
 
 
 T_FN_ARGS = TypeVar("T_FN_ARGS")
